@@ -75,31 +75,6 @@
 #'# should not calculate FOG, because FOG.hard.words is missing:
 #'readability.num(test.features, index="all")
 #'}
-#'
-#' @usage readability.num(
-#'      txt.features=list(
-#'        sentences=NULL,
-#'        words=NULL,
-#'        letters=c(all=0, l5=0, l6=0),
-#'        syllables=c(all=0, s1=0, s2=0),
-#'        punct=NULL,
-#'        all.chars=NULL,
-#'        prepositions=NULL,
-#'        conjunctions=NULL,
-#'        pronouns=NULL,
-#'        foreign=NULL,
-#'        TTR=NULL,
-#'        FOG.hard.words=NULL,
-#'        Bormuth.NOL=NULL,
-#'        Dale.Chall.NOL=NULL,
-#'        Harris.Jacobson.NOL=NULL,
-#'        Spache.NOL=NULL),
-#'      index=c("ARI", "Bormuth", "Coleman", "Coleman.Liau",
-#'        "Dale.Chall", "Danielson.Bryan", "Dickes.Steiwer","DRP",
-#'        "ELF", "Farr.Jenkins.Paterson", "Flesch", "Flesch.Kincaid",
-#'        "FOG", "FORCAST", "Fucks", "Harris.Jacobson", "Linsear.Write", "LIX", "nWS",
-#'        "RIX", "SMOG", "Spache", "Strain", "Traenkle.Bailer", "TRI", "Wheeler.Smith"),
-#'      parameters=list(), ...)
 #' @export
 
 readability.num <- function(
@@ -124,7 +99,8 @@ readability.num <- function(
         "Dale.Chall", "Danielson.Bryan", "Dickes.Steiwer","DRP",
         "ELF", "Farr.Jenkins.Paterson", "Flesch", "Flesch.Kincaid",
         "FOG", "FORCAST", "Fucks", "Harris.Jacobson", "Linsear.Write", "LIX", "nWS",
-        "RIX", "SMOG", "Spache", "Strain", "Traenkle.Bailer", "TRI", "Wheeler.Smith"),
+        "RIX", "SMOG", "Spache", "Strain", "Traenkle.Bailer", "TRI", "Tuldava",
+        "Wheeler.Smith"),
       parameters=list(), ...){
 
   # check if txt.features is a readability result, and
@@ -160,7 +136,7 @@ readability.num <- function(
       "Flesch.PSK", "Flesch.Szigriszt", "FOG", "FOG.NRI", "FOG.PSK", "FORCAST", "FORCAST.RGL",
       "Fucks", "Harris.Jacobson", "Linsear.Write", "LIX", "nWS", "RIX", "SMOG", "SMOG.C",
       "SMOG.de", "SMOG.simple", "Spache", "Spache.de", "Spache.old", "Strain", "Traenkle.Bailer", "TRI",
-      "Wheeler.Smith", "Wheeler.Smith.de")
+      "Tuldava", "Wheeler.Smith", "Wheeler.Smith.de")
   # activate all?
   if(identical(index, "all")){
     index <- all.valid.fixed.indices
@@ -177,10 +153,10 @@ readability.num <- function(
     "Flesch", "Flesch.de", "Flesch.es", "Flesch.fr", "Flesch.Kincaid", "Flesch.nl",
     "Flesch.PSK", "Flesch.Szigriszt", "FOG", "FOG.NRI", "FOG.PSK", "FORCAST", "FORCAST.RGL",
     "Linsear.Write", "nWS", "SMOG", "SMOG.C", "SMOG.de", "SMOG.simple", "Strain", "TRI",
-    "Wheeler.Smith", "Wheeler.Smith.de")
+    "Tuldava", "Wheeler.Smith", "Wheeler.Smith.de")
   # these indices are ok with only the global number of syllables
   global.sylls.ok <- c("Coleman", "Flesch", "Flesch.de", "Flesch.es", "Flesch.fr", "Flesch.Kincaid",
-    "Flesch.nl", "Flesch.PSK", "Flesch.Szigriszt", "Strain")
+    "Flesch.nl", "Flesch.PSK", "Flesch.Szigriszt", "Strain", "Tuldava")
   # check if we have syllables, if needed
   if(any(index %in% need.sylls)){
     # if a global number is ok, rewrite the given value to remain compatible nonetheless
